summaryrefslogtreecommitdiff
path: root/compiler/GHC/Hs/Decls.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/Hs/Decls.hs')
-rw-r--r--compiler/GHC/Hs/Decls.hs10
1 files changed, 5 insertions, 5 deletions
diff --git a/compiler/GHC/Hs/Decls.hs b/compiler/GHC/Hs/Decls.hs
index e5e64267bf..bc0aaff318 100644
--- a/compiler/GHC/Hs/Decls.hs
+++ b/compiler/GHC/Hs/Decls.hs
@@ -1028,13 +1028,13 @@ type instance Anno (SourceText, RuleName) = SrcSpan
data HsRuleAnn
= HsRuleAnn
- { ra_tyanns :: Maybe (AddApiAnn, AddApiAnn)
+ { ra_tyanns :: Maybe (AddEpAnn, AddEpAnn)
-- ^ The locations of 'forall' and '.' for forall'd type vars
- -- Using AddApiAnn to capture possible unicode variants
- , ra_tmanns :: Maybe (AddApiAnn, AddApiAnn)
+ -- Using AddEpAnn to capture possible unicode variants
+ , ra_tmanns :: Maybe (AddEpAnn, AddEpAnn)
-- ^ The locations of 'forall' and '.' for forall'd term vars
- -- Using AddApiAnn to capture possible unicode variants
- , ra_rest :: [AddApiAnn]
+ -- Using AddEpAnn to capture possible unicode variants
+ , ra_rest :: [AddEpAnn]
} deriving (Data, Eq)
flattenRuleDecls :: [LRuleDecls (GhcPass p)] -> [LRuleDecl (GhcPass p)]